| bahai_date | R Documentation |
The Bahá'í calendar is a solar calendar used in the Bahá'í faith comprising 18 months, with four or five intercalary days each year. The New Year is at the northern Spring equinox, corresponding to 21 March on the Gregorian calendar. Ayyám-i-Há is specified as month 20.
bahai_date(
major = integer(),
cycle = integer(),
year = integer(),
month = integer(),
day = integer()
)
as_bahai(date)
major |
A numeric vector of major periods |
cycle |
A numeric vector of cycles |
year |
A numeric vector of years within the cycles |
month |
A numeric vector of months |
day |
A numeric vector of days |
date |
A numeric vector of dates |
A bahai vector object
cal_bahai, bahai_new_year
tibble::tibble(
gregorian = gregorian_date(2025, 2, 15) + 0:30,
bahai = as_bahai(gregorian)
)
bahai_date(1, 10, 11, 3, 5:7)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.