| calcal-package | R Documentation |
An R implementation of the algorithms described in Reingold and Dershowitz (4th ed., Cambridge University Press, 2018) \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1017/9781107415058")}, allowing conversion between many different calendar systems. Cultural and religious holidays from several calendars can be calculated.
Maintainer: Rob Hyndman Rob.Hyndman@monash.edu (ORCID) [copyright holder]
Other contributors:
Edward Reingold (Original Lisp code) [copyright holder, contributor]
Nachum Dershowitz (Original Lisp code) [copyright holder, contributor]
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.