| advent | R Documentation |
Functions to return Gregorian dates for various Christian ecclesiastical holidays and other special days
Coptic Christmas is celebrated on 29th of Koiak in the Coptic calendar, which currently corresponds to 7 or 8 January in the Gregorian calendar.
advent(year)
christmas(year)
orthodox_christmas(year)
epiphany(year)
easter(year)
orthodox_easter(year)
pentecost(year)
coptic_christmas(year)
astronomical_easter(year)
year |
Gregorian year |
A vector of dates on the Gregorian calendar
tibble::tibble(
year = 2025:2030,
advent = advent(year),
christmas = christmas(year),
orthodox_christmas = orthodox_christmas(year),
epiphany = epiphany(year),
easter = easter(year),
orthodox_easter = orthodox_easter(year),
pentecost = pentecost(year)
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.