| french_date | R Documentation |
There are two versions of the French Revolutionary Calendar. The original version, used from 1793, was kept in sync with the solar year by setting the first day of Vendemiaire to the autumnal equinox. The second version, proposed in 1795, was a simpler arithmetic calendar, but was never used. We distinguish the two by using "afrench" (for Arithmetic French) for the second form.
french_date(year = integer(), month = integer(), day = integer())
afrench_date(year = integer(), month = integer(), day = integer())
as_french(date)
as_afrench(date)
year |
year |
month |
month |
day |
day |
date |
A vector of dates on some calendar |
A vector of dates on the French Revolutionary calendar
french_date(1, 1, 1:15) |>
as_gregorian()
french_date(1, 1, 1:15) |>
day_of_week()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.