| hindu_solar_date | R Documentation |
There are four Hindu calendars implemented: modern Hindu solar and lunar calendars, and the old Hindu solar and lunar calendars. Hindu solar months are 1/12 of a solar year (approximately 30.44 days), while lunar months are based on the lunar cycle (approximately 29.53 days).
hindu_solar_date(year, month, day)
hindu_lunar_date(year, month, leap_month, day, leap_day)
as_hindu_solar(date)
as_hindu_lunar(date)
old_hindu_solar_date(year = integer(), month = integer(), day = integer())
old_hindu_lunar_date(
year = integer(),
month = integer(),
leap_month = logical(),
day = integer()
)
as_old_hindu_solar(date)
as_old_hindu_lunar(date)
year |
A numeric vector of years |
month |
A numeric vector of months |
day |
A numeric vector of days |
leap_month |
A logical vector indicating if year is a leap year |
leap_day |
A logical vector indicating if day is a leap day |
date |
A date vector on some calendar |
A vector object of Hindu dates.
cal_hindu_solar, cal_hindu_lunar, cal_old_hindu_solar, cal_old_hindu_lunar, diwali
gregorian_date(2025, 1, 1:31) |>
as_hindu_solar()
gregorian_date(2025, 1, 1:31) |>
as_hindu_lunar()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.