| icelandic_date | R Documentation |
The Icelandic calendar, still in use in Iceland, divides times into 7-day weeks and two seasons: Summer and Winter. Summer starts on the first Thursday after April 18th, and Winter 180 days earlier. Ordinary years have 52 weeks with leap years having 53 weeks. The leap week occurs every 5-7 years in midsummer.
icelandic_date(
year = integer(),
season = integer(),
week = integer(),
weekday = integer()
)
as_icelandic(date)
year |
A numeric vector of years |
season |
A numeric vector of seasons (1 = Summer, 2 = Winter) |
week |
A numeric vector of weeks within the season (1 to 28) |
weekday |
A number vector containing day of week (0 = Sunday, 1 = Monday, ..., 6 = Saturday)) |
date |
A numeric vector of dates |
An icelandic vector object
gregorian_date(2025, 4, 20:30) |>
as_icelandic()
icelandic_date(2025, 1, 6, 0:6) |>
day_of_week()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.