| islamic_new_year | R Documentation |
Functions to return Gregorian dates for various Islamic holidays. Specific dates can vary slightly based on moon sightings in different regions.
islamic_new_year(year)
mawlid(year)
ramadan(year)
eid_al_fitr(year)
eid_al_adha(year)
year |
A numeric vector of Gregorian years |
A vector of dates on the Gregorian calendar
islamic_date
tibble::tibble(
year = 2025:2029,
`New year` = islamic_new_year(year),
Mawlid = mawlid(year),
Ramadan = ramadan(year),
`Eid al-Fitr` = eid_al_fitr(year),
`Eid al-Adha` = eid_al_adha(year)
)
ramadan(2030)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.