| location | R Documentation |
Create a location object. These are used for calculating the timing of astronomical events such as sunrise and sunset.
location(
latitude = numeric(),
longitude = numeric(),
elevation = numeric(),
zone = numeric()
)
latitude |
A numeric vector of latitudes |
longitude |
A numeric vector of longitudes |
elevation |
A numeric vector of elevations above sea level (in metres) |
zone |
A numeric vector of time zones (in hours, relative to UTC) |
A location vector object
melbourne <- location(-37.8136, 144.9631, 31, 10)
sunrise("2025-01-01", melbourne)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.