| lunar_phase | R Documentation |
Lunar phase at date, as an angle in degrees. An angle of 0 means a new moon, 90 degrees means the first quarter, 180 means a full moon, and 270 degrees means the last quarter.
lunar_phase(date)
date |
Date vector |
A numeric vector of angles in degrees representing the lunar phase at the given dates.
april2025 <- gregorian_date(2025, 4, 1:30)
lunar_phase(april2025)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.