| mayan_date | R Documentation |
There are three Mayan calendars: the famous "long count" calendar, the "Haab" calendar, and the "Tzolkin" calendar. Of these, only the long count calendar can be converted to and from other calendars, so it is the only one that has been implemented here.
mayan_date(
baktun = integer(),
katun = integer(),
tun = integer(),
uinal = integer(),
kin = integer()
)
as_mayan(date)
baktun |
Numeric vector |
katun |
Numeric vector |
tun |
Numeric vector |
uinal |
Numeric vector |
kin |
Numeric vector |
date |
Vector of dates on some calendar |
The Mayan long count calendar is a vigesimal (base-20) calendar with five components: kin (1 day), uinal (20 kin), tun (18 uinal), katun (20 tun), and baktun (20 katun). So the full cycle repeats every 20x18x20x20 = 144,000 days (approximately 394 years).
A mayan vector object
cal_mayan
gregorian_date(2012, 12, 10:30) |>
as_mayan()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.