| sunrise | R Documentation |
Calculate the time of sunrise, sunset, moonrise and moonset at a specific location and date. The
time zone of the location is used as specified in the location object. No adjustments are made for
daylight saving.
sunrise(date, location)
sunset(date, location)
moonset(date, location)
moonrise(date, location)
date |
Vector of dates on some calendar. |
location |
Vector of locations of class "location", usually the output from the |
Time of sunrise
melbourne <- location(-37.8136, 144.9631, 31, 10)
sydney <- location(-33.8688, 151.2093, 3, 10)
sunrise(gregorian_date(2025, 1, 1), c(melbourne, sydney))
sunset(gregorian_date(2025, 1, 1), c(melbourne, sydney))
moonrise(gregorian_date(2025, 1, 1), c(melbourne, sydney))
moonset(gregorian_date(2025, 1, 1), c(melbourne, sydney))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.