| tibetan_date | R Documentation |
There are several Tibetan calendars. These functions implement the official Phuglugs version of the Kalachakra calendar, which is similar to the Hindu lunisolar calendars.
tibetan_date(
year = integer(),
month = integer(),
leap_month = logical(),
day = integer(),
leap_day = logical()
)
as_tibetan(date)
year |
A numeric vector of years |
month |
A numeric vector of months |
leap_month |
A logical vector of leap months |
day |
A numeric vector of days |
leap_day |
A logical vector of leap days |
date |
A vector of dates on some calendar |
A tibetan_date object
tibetan_new_year
gregorian_date(2025, 6, 1:10) |> as_tibetan()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.