| tibetan_new_year | R Documentation |
The Tibetan New Year occurs on the first day of the Tibetan calendar. These functions calculate the date given either a Gregorian year or a Tibetan year. Both return a Gregorian date.
tibetan_new_year(year)
losar(t_year)
year |
A vector of Gregorian years |
t_year |
A vector of Tibetan years |
A vector of Gregorian dates corresponding to the Tibetan New Year
tibetan_date
tibetan_new_year(2025:2028)
losar(2152:2154)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.